@@ -85,7 +85,7 @@ class SteeringIDDS():
         old format
         {"points": [[{hyperparameter_point_1}, <loss_or_None>], ..., [{hyperparameter_point_N}, <loss_or_None>]], "opt_space": <opt space>}
         new format
-        {"points": [[<model_id_1>, {hyperparameter_point_1}, <loss_or_None>], ..., [<model_id_N>, {hyperparameter_point_N}, <loss_or_None>]], "opt_space": ["model_id": <model_id>, "search_space": <search_space>]}
+        {"points": [[[<model_id_1>, {hyperparameter_point_1}], <loss_or_None>], ..., [[<model_id_N>, {hyperparameter_point_N}], <loss_or_None>]], "opt_space": ["model_id": <model_id>, "search_space": <search_space>]}
         '''
         keys = ['points', 'opt_space']
         # check main keys
@@ -99,8 +99,9 @@ class SteeringIDDS():
         for point in idds_input['points']:
             if not isinstance(point, List):
                 raise ValueError('idds should have the data structure: Dict[List[List[...]]]')
-            if not isinstance(point[0], (Dict, int)):
-                raise ValueError('idds should have the data structure: Dict[List[List[Dict, Value]]] or Dict[List[List[int, Dict, Value]]]')
+            
+            if (not isinstance(point[0], Dict)) and (not (isinstance(point[0], List) and isinstance(point[0][0], int) and isinstance(point[0][1], Dict))):
+                raise ValueError('idds should have the data structure: Dict[List[List[Dict, Value]]] or Dict[List[List[List[int, Dict], Value]]]')
         # old format
         if isinstance(idds_input['opt_space'], Dict):
             return 1
