@@ -4,6 +4,7 @@ import json
 import fnmatch
 import argparse
 
+from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.utils import stylus
 
 kDefultGridSiteType = ['analysis', 'unified']
@@ -11,11 +12,13 @@ kDefaultGridSiteInfo = ['state', 'status', 'maxinputsize', 'maxmemory', 'maxtime
 
 class GridSiteInfo():
     
+    _USAGE_ = 'hpogrid sites [<args>]'
+    _DESCRIPTION_ = 'Tool for retrieving grid site information'      
+    
     @staticmethod
-    def get_parser():
-        parser = argparse.ArgumentParser(description='Show grid site information',
-                                         usage='hpogrid sites [<args>]',
-                    formatter_class=argparse.RawDescriptionHelpFormatter)          
+    def get_parser(**kwargs):
+        parser = CLIParser(description=GridSiteInfo._DESCRIPTION_,
+                           usage=GridSiteInfo._USAGE_, **kwargs)           
         parser.add_argument('-n', '--name', metavar='',help='filter grid site names')
         parser.add_argument('-g', '--non_gpu', action='store_true',
             help='show also non gpu sites')
@@ -24,18 +27,16 @@ class GridSiteInfo():
         parser.add_argument('-t', '--site_type', metavar='',nargs='+',
             help='filter sites by type', default=kDefultGridSiteType)
         parser.add_argument('-i', '--info', metavar='',nargs='+',
-            help='into to show', default=kDefaultGridSiteInfo)
+            help='list of info to show', default=kDefaultGridSiteInfo)
         return parser
     
     @staticmethod
     def run_parser(args=None):
         parser = GridSiteInfo.get_parser()
-        if args is None:
-            args = sys.argv[2:]
-        kwargs = vars(parser.parse_args(args))
-        kwargs['gpu'] = not kwargs.pop('non_gpu', 'False')
-        kwargs['active'] = not kwargs.pop('non_active', 'False')
-        GridSiteInfo.show(**kwargs)
+        args = vars(parser.parse_args(args))
+        args['gpu'] = not args.pop('non_gpu', False)
+        args['active'] = not args.pop('non_active', False)
+        GridSiteInfo.show(**args)
 
     @staticmethod
     def show(name=None, gpu=True, active=True, site_type=kDefultGridSiteType,
